@@ -19,6 +19,7 @@ import collections
 import copy
 import json
 import os
+import sys
 import warnings
 
 import appdirs
@@ -26,6 +27,7 @@ from keystoneauth1 import adapter
 from keystoneauth1 import loading
 import yaml
 
+from os_client_config import _log
 from os_client_config import cloud_config
 from os_client_config import defaults
 from os_client_config import exceptions
@@ -170,6 +172,8 @@ class OpenStackConfig(object):
     def __init__(self, config_files=None, vendor_files=None,
                  override_defaults=None, force_ipv4=None,
                  envvar_prefix=None, secure_files=None):
+        self.log = _log.setup_logging(__name__)
+
         self._config_files = config_files or CONFIG_FILES
         self._secure_files = secure_files or SECURE_FILES
         self._vendor_files = vendor_files or VENDOR_FILES
@@ -312,7 +316,7 @@ class OpenStackConfig(object):
                         return path, json.load(f)
                     else:
                         return path, yaml.safe_load(f)
-        return (None, None)
+        return (None, {})
 
     def _normalize_keys(self, config):
         new_config = {}
@@ -444,7 +448,7 @@ class OpenStackConfig(object):
         if 'cloud' in cloud:
             del cloud['cloud']
 
-        return self._fix_backwards_madness(cloud)
+        return cloud
 
     def _expand_vendor_profile(self, name, cloud, our_cloud):
         # Expand a profile if it exists. 'cloud' is an old confusing name
@@ -893,6 +897,8 @@ class OpenStackConfig(object):
         if 'endpoint_type' in config:
             config['interface'] = config.pop('endpoint_type')
 
+        config = self._fix_backwards_madness(config)
+
         for key in BOOL_KEYS:
             if key in config:
                 if type(config[key]) is not bool:
@@ -920,6 +926,7 @@ class OpenStackConfig(object):
                 # but OSC can't handle it right now, so we try deferring
                 # to ksc. If that ALSO fails, it means there is likely
                 # a deeper issue, so we assume the ksa error was correct
+                self.log.debug("Deferring keystone exception: {e}".format(e=e))
                 auth_plugin = None
                 try:
                     config = self._validate_auth_ksc(config)
@@ -984,4 +991,15 @@ class OpenStackConfig(object):
 if __name__ == '__main__':
     config = OpenStackConfig().get_all_clouds()
     for cloud in config:
-        print(cloud.name, cloud.region, cloud.config)
+        print_cloud = False
+        if len(sys.argv) == 1:
+            print_cloud = True
+        elif len(sys.argv) == 3 and (
+                sys.argv[1] == cloud.name and sys.argv[2] == cloud.region):
+            print_cloud = True
+        elif len(sys.argv) == 2 and (
+                sys.argv[1] == cloud.name):
+            print_cloud = True
+
+        if print_cloud:
+            print(cloud.name, cloud.region, cloud.config)
